#!/usr/bin/env python2
# Thomas Levine, ScraperWiki Limited

'''
Local version of ScraperWiki Utils, documentation here:
https://scraperwiki.com/docs/python/python_help_documentation/
'''

from .utils import scrape, pdftoxml, status
import utils, sqlite

sql = sqlite

